@@ -66,7 +66,7 @@ pub async fn get_raw(
 
         // Then, check the files
         let files = connection
-            .retrieve_file(hash)
+            .retrieve_file(&hash)
             .map_err(ErrorInternalServerError)?;
         if let Some(file) = files.get(0) {
             let file_path = state.upend.vault_path.join(&file.path);
@@ -126,6 +126,45 @@ pub async fn get_raw(
     }
 }
 
+
+#[get("/api/thumb/{hash}")]
+pub async fn get_thumbnail(
+    state: web::Data<State>,
+    hash: web::Path<String>,
+) -> Result<Either<NamedFile, HttpResponse>, Error> {
+    #[cfg(feature = "previews")]
+    if let Some(preview_store) = &state.preview_store {
+        let hash = hash.into_inner();
+        let address = Address::decode(&b58_decode(&hash).map_err(ErrorInternalServerError)?)
+            .map_err(ErrorInternalServerError)?;
+        if let Address::Hash(address_hash) = address {
+            let preview_store = preview_store.clone();
+            let preview_result = web::block(move || preview_store.get(address_hash)).await?;
+
+            if let Some(preview_path) = preview_result {
+                let mut file = NamedFile::open(&preview_path)?.disable_content_disposition();
+                if let Some(mime_type) = tree_magic_mini::from_filepath(&preview_path) {
+                    if let Ok(mime) = mime_type.parse() {
+                        file = file.set_content_type(mime);
+                    }
+                }
+                return Ok(Either::A(file));
+            } else {
+                return Ok(Either::B(
+                    HttpResponse::SeeOther()
+                        .header(http::header::LOCATION, format!("/api/raw/{hash}"))
+                        .finish(),
+                ));
+            }
+        } else {
+            return Err(ErrorBadRequest(
+                "Address does not refer to a previewable object.",
+            ));
+        }
+    }
+    Err(error::ErrorNotImplemented("Previews not enabled."))
+}
+
 #[derive(Deserialize)]
 pub struct QueryRequest {
     query: String,
@@ -229,7 +268,7 @@ pub async fn put_object(
                 let connection = state.upend.connection().map_err(ErrorInternalServerError)?;
 
                 let existing_files = connection
-                    .retrieve_file(hash.clone())
+                    .retrieve_file(&hash)
                     .map_err(ErrorInternalServerError)?;
 
                 if existing_files.is_empty() {
@@ -426,7 +465,7 @@ pub async fn get_file(
     if let Address::Hash(hash) = address {
         let connection = state.upend.connection().map_err(ErrorInternalServerError)?;
         let response = connection
-            .retrieve_file(hash)
+            .retrieve_file(&hash)
             .map_err(ErrorInternalServerError)?;
 
         Ok(HttpResponse::Ok().json(response))
@@ -455,44 +494,7 @@ pub async fn get_info(state: web::Data<State>) -> Result<HttpResponse, Error> {
     Ok(HttpResponse::Ok().json(json!({
         "name": state.vault_name,
         "location": &*state.upend.vault_path,
-        "version": crate::common::PKG_VERSION
+        "version": crate::common::PKG_VERSION,
+        "desktop": state.desktop_enabled
     })))
 }
-
-#[get("/api/thumb/{hash}")]
-pub async fn get_thumbnail(
-    state: web::Data<State>,
-    hash: web::Path<String>,
-) -> Result<Either<NamedFile, HttpResponse>, Error> {
-    #[cfg(feature = "previews")]
-    if let Some(preview_store) = &state.preview_store {
-        let hash = hash.into_inner();
-        let address = Address::decode(&b58_decode(&hash).map_err(ErrorInternalServerError)?)
-            .map_err(ErrorInternalServerError)?;
-        if let Address::Hash(address_hash) = address {
-            let preview_store = preview_store.clone();
-            let preview_result = web::block(move || preview_store.get(address_hash)).await?;
-
-            if let Some(preview_path) = preview_result {
-                let mut file = NamedFile::open(&preview_path)?.disable_content_disposition();
-                if let Some(mime_type) = tree_magic_mini::from_filepath(&preview_path) {
-                    if let Ok(mime) = mime_type.parse() {
-                        file = file.set_content_type(mime);
-                    }
-                }
-                return Ok(Either::A(file));
-            } else {
-                return Ok(Either::B(
-                    HttpResponse::SeeOther()
-                        .header(http::header::LOCATION, format!("/api/raw/{hash}"))
-                        .finish(),
-                ));
-            }
-        } else {
-            return Err(ErrorBadRequest(
-                "Address does not refer to a previewable object.",
-            ));
-        }
-    }
-    Err(error::ErrorNotImplemented("Previews not enabled."))
-}
